==> je_auto_control_dev-0.0.66.tar.gz: je_auto_control_dev-0.0.66/je_auto_control/utils/project/template/template_keyword.py <==
template_keyword_1: list = [
    ["set_record_enable", [True]],
    ["write", {"write_string": "Hello World"}],
    ["type_keyboard", {"keycode": "return"}],
    ["write", {"write_string": "If you want Windows write upcase string"}],
    ["type_keyboard", {"keycode": "return"}],
    ["write", {"write_string": "you need to press shift first"}],
    ["type_keyboard", {"keycode": "return"}],
    ["press_keyboard_key", {"keycode": "shift"}],
    ["write", {"write_string": "UPCASEE"}],
    ["release_keyboard_key", {"keycode": "shift"}],
    ["type_keyboard", {"keycode": "return"}],
    ["write", {"write_string": "this is example how to use keyword"}],
    ["write", {"write_string": " and add module to executor"}],
    ["type_keyboard", {"keycode": "return"}],
    ["write", {"write_string": "now i will add time module and sleep 3 sec"}],
    ["add_package_to_executor", ["time"]],
    ["time_sleep", [3]],
    ["type_keyboard", {"keycode": "return"}],
    ["write", {"write_string": "also you can use builtin function on executor like print"}],
    ["print", ["Google Bye World"]],
    ["type_keyboard", {"keycode": "return"}],
    ["write", {"write_string": "and i will create an html report for you"}],
    ["generate_html_report"],
    ["type_keyboard", {"keycode": "return"}]
]

template_keyword_2: list = [
    ["set_record_enable", [True]],
    ["write", {"write_string": "in this keyword file we will change the mouse position"}],
    ["type_keyboard", {"keycode": "return"}],
    ["set_mouse_position", [500, 500]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["set_mouse_position", [600, 600]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["set_mouse_position", [400, 400]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["set_mouse_position", [300, 300]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["set_mouse_position", [200, 200]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["set_mouse_position", [700, 700]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["set_mouse_position", [800, 800]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["write", {"write_string": "now i will create an json report for you"}],
    ["type_keyboard", {"keycode": "return"}],
    ["generate_json_report"]
]

==> je_auto_control_dev-0.0.69.tar.gz: je_auto_control_dev-0.0.69/je_auto_control/utils/project/template/template_keyword.py <==
template_keyword_1: list = [
    ["set_record_enable", [True]],
    ["write", {"write_string": "Hello World"}],
    ["type_keyboard", {"keycode": "return"}],
    ["write", {"write_string": "If you want Windows write upcase string"}],
    ["type_keyboard", {"keycode": "return"}],
    ["write", {"write_string": "you need to press shift first"}],
    ["type_keyboard", {"keycode": "return"}],
    ["press_keyboard_key", {"keycode": "shift"}],
    ["write", {"write_string": "UPCASEE"}],
    ["release_keyboard_key", {"keycode": "shift"}],
    ["type_keyboard", {"keycode": "return"}],
    ["write", {"write_string": "this is example how to use keyword"}],
    ["write", {"write_string": " and add module to executor"}],
    ["type_keyboard", {"keycode": "return"}],
    ["write", {"write_string": "now i will add time module and sleep 3 sec"}],
    ["add_package_to_executor", ["time"]],
    ["time_sleep", [3]],
    ["type_keyboard", {"keycode": "return"}],
    ["write", {"write_string": "also you can use builtin function on executor like print"}],
    ["print", ["Google Bye World"]],
    ["type_keyboard", {"keycode": "return"}],
    ["write", {"write_string": "and i will create an html report for you"}],
    ["generate_html_report"],
    ["type_keyboard", {"keycode": "return"}]
]

template_keyword_2: list = [
    ["set_record_enable", [True]],
    ["write", {"write_string": "in this keyword file we will change the mouse position"}],
    ["type_keyboard", {"keycode": "return"}],
    ["set_mouse_position", [500, 500]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["set_mouse_position", [600, 600]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["set_mouse_position", [400, 400]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["set_mouse_position", [300, 300]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["set_mouse_position", [200, 200]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["set_mouse_position", [700, 700]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["set_mouse_position", [800, 800]],
    ["set_mouse_position", {"x": 100, "y": 100}],
    ["write", {"write_string": "now i will create an json report for you"}],
    ["type_keyboard", {"keycode": "return"}],
    ["generate_json_report"]
]

bad_template_1 = [
    ["set_record_enable", [True]],
    ["add_package_to_executor", ["os"]],
    ["os_system", ["python --version"]],
    ["os_system", ["python -m pip --version"]],
]
